function dragDemo
%% Demonstrate dragging patch objects 
%          - C.S. Lent

%% get handle to axes object (change for use in GUI Tool)
cla(gca);
hAx=gca;
axis(hAx,'on');
grid(hAx,'on');

%% setup patch object on axis
axis([0 10 0 5]);
hpatch1=patch([1 2 2 1 1],[2.2  2  3.2  3 2.2],'r',...
              'Parent',hAx);
hpatch2=patch([5 8 9 5 5],[2.2  2  3.2  3 2.2],'g',...
              'Parent',hAx);

%% set callbacks for button click and motion
set(hpatch1,'ButtonDownFcn',{@myButtonDownFcn,hpatch1}); 
set(hpatch2,'ButtonDownFcn',{@myButtonDownFcn,hpatch2}); 
set(gcf,'WindowButtonUpFcn',{@myButtonUpFcn,gcf});  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
%% Button Functions
function myButtonDownFcn(hThis,eventdata,varargin)
    % when the object is clicked, set the motion function
    %  The offset is the difference between the Reference point
    %  of the object (x(1),y(1)) and the mouse position when button
    %  was pushed down. 
    X=get(hThis,'XData');
    Y=get(hThis,'YData');
    RefPoint=[X(1),Y(1)];
    curr_pt = get(gca,'CurrentPoint');
    offset=RefPoint-[curr_pt(1,1),curr_pt(1,2)];
    
    set(gcf,'WindowButtonMotionFcn',{@myButtonMotionFcn,hThis,offset});

function myButtonUpFcn(src,eventdata,varargin);
    % when the button is released, null out the motion function
    set(gcf,'WindowButtonMotionFcn',' ');

function myButtonMotionFcn(src,eventdata,hThis,offset)
    %  Moves the object with handle hThis.
    %  The offset is the difference between the lower left
    %  of the object and the mouse position when button
    %  was pushed down. 
    
    % Get x and y positions of vertices and zero to 1st point
    X=hThis.XData;
    Y=hThis.YData;
    Xrel=X-X(1);
    Yrel=Y-Y(1);
    
    % Get the mouse cursor Location
    curr_pt = get(gca,'CurrentPoint');
    
    % Change the position of the object
     hThis.XData=curr_pt(1,1)+offset(1)+Xrel;
     hThis.YData=curr_pt(1,2)+offset(2)+Yrel;


