function dragFogHorn
% Demonstrate dragging image object against background
% image                - C. Lent
clf

%%  store handle to axes on which everything should appear
%       (change for use in GUI Tool)
hAx=gca;

%% load in images and flip for cartesian display
fogimage=imread('Foghorn-Leghorn.jpg');
fogmask=imread('Foghorn-LeghornMask.jpg');
bluehills=imread('Blue hills.jpg');

for k=1:3
   fogimage(:,:,k)=flipud(fogimage(:,:,k));
   bluehills(:,:,k)=flipud(bluehills(:,:,k));
end
fogmask=flipud(fogmask)/255;

%% setup scaling -- 
[ny, nx, n]=size(fogimage);
imratio=ny/nx;
imwidth=1.2;  % picked just for demo purposes
imheight=imwidth*imratio;

xmin=0; 
ymin=0; 
xmax=3;
ymax=2;

%% create background
hb=image('CData',bluehills,'Parent',hAx);
set(hb,'XData', [xmin xmax]);
set(hb,'YData', [ymin ymax]);

%% create foghorn image
him=image('CData',fogimage,'AlphaData',~fogmask,'Parent',hAx);

imx0=0;
imy0=0;
set(him,'XData',[imx0 imx0+imwidth]);
set(him,'YData',[imy0 imy0+imheight]);

axis equal
axis([xmin xmax ymin ymax]);
axis off

% set callbacks for button click and motion
set(him,'ButtonDownFcn',{@myButtonDownFcn,him}); 
set(gcf,'WindowButtonUpFcn',{@myButtonUpFcn,gcf}); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
%% Button Functions
function myButtonDownFcn(hThis,eventdata,varargin)
    % when the object is clicked, set the motion function
    %  The offset is the difference between the Reference point
    %  of the object (x(1),y(1)) and the mouse position when button
    %  was pushed down. 
    X=get(hThis,'XData');
    Y=get(hThis,'YData');
    RefPoint=[X(1),Y(1)];
    curr_pt = get(gca,'CurrentPoint');
    offset=RefPoint-[curr_pt(1,1),curr_pt(1,2)];
    
    set(gcf,'WindowButtonMotionFcn',{@myButtonMotionFcn,hThis,offset});

function myButtonUpFcn(src,eventdata,varargin);
    % when the button is released, null out the motion function
    set(gcf,'WindowButtonMotionFcn',' ');

function myButtonMotionFcn(src,eventdata,hThis,offset)
    %  Moves the object with handle hThis.
    %  The offset is the difference between the lower left
    %  of the object and the mouse position when button
    %  was pushed down. 
    
    % Get x and y positions of vertices and zero to 1st point
    X=hThis.XData;
    Y=hThis.YData;
    Xrel=X-X(1);
    Yrel=Y-Y(1);
    
    % Get the mouse cursor Location
    curr_pt = get(gca,'CurrentPoint');
    
    % Change the position of the object
     hThis.XData=curr_pt(1,1)+offset(1)+Xrel;
     hThis.YData=curr_pt(1,2)+offset(2)+Yrel;


